package com.cardiff.client_project.mapper;

import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.pojo.vo.NurseVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.List;

@Repository
public class CommonAdminHospitalMapper {

    @Autowired
    JdbcTemplate jdbcTemplate;

    // 更新医院信息
    public int update(HospitalDTO hospital) {
        String sql = "UPDATE hospital SET name=?, address=?, phone=?, totalBeds=?, availableBeds=?, occupancyRate=? WHERE id=?";
        return jdbcTemplate.update(sql, hospital.getName(), hospital.getAddress(), hospital.getPhone(),
                hospital.getTotalBeds(), hospital.getAvailableBeds(), hospital.getOccupancyRate(), hospital.getId());
    }

    public List<NurseVO> findAllNurses() {
        String sql = "SELECT id, name, status, " +
                "CASE WHEN status = 1 THEN 'Active' ELSE 'Inactive' END AS status_str, " +
                "hospitalId, type AS gender, age, address, email, phone " +
                "FROM nurse";
        return jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(NurseVO.class));
    }

    public List<NurseVO> searchNurses(String name, Integer hospitalId) {
        StringBuilder sql = new StringBuilder("SELECT id, name, status, ");
        sql.append("CASE WHEN status = 1 THEN 'Active' ELSE 'Inactive' END AS status_str, ");
        sql.append("hospitalId, type AS gender, age, address, email, phone ");
        sql.append("FROM nurse WHERE 1=1");

        List<Object> params = new ArrayList<>();
        if (name != null && !name.isEmpty()) {
            sql.append(" AND name LIKE ?");
            params.add("%" + name + "%");
        }
        if (hospitalId != null) {
            sql.append(" AND hospitalId = ?");
            params.add(hospitalId);
        }

        return jdbcTemplate.query(sql.toString(), params.toArray(), new BeanPropertyRowMapper<>(NurseVO.class));
    }

}
