package com.cardiff.client_project.mapper;

import com.cardiff.client_project.constant.ResponseCode;
import com.cardiff.client_project.pojo.entity.Device;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.simple.SimpleJdbcInsert;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Repository
public class DeviceMapper {
    @Autowired
    JdbcTemplate jdbcTemplate;

    /**
     * update device data
     * @param device
     * @return
     */
    public int update(Device device) {
        String sql = "UPDATE device SET name = ?,type = ?, freetime=?,hospitalId =?, id =? WHERE id = ?";
        int update = jdbcTemplate.update(sql, preparedStatement -> {
            preparedStatement.setString(1, device.getName());
            preparedStatement.setString(2, device.getType());
            preparedStatement.setDate(3, device.getFreeTime());
            preparedStatement.setInt(4, device.getHospitalId());
            preparedStatement.setInt(5, device.getId());
            preparedStatement.setInt(6, device.getId());
        });
        return update;
    }

    /**
     * Batch deletion based on id
     * @param ids
     * @return
     */
    public int[] deleteByIdAndType(List<Integer> ids, String type) {
        String sql = "DELETE FROM device WHERE id=?";
        String sql_1="ALTER TABLE device DROP COLUMN id;";
        String sql_2="ALTER TABLE device ADD COLUMN id INT NOT NULL PRIMARY KEY AUTO_INCREMENT FIRST;";

        List<Object[]> idList = new ArrayList<>();
        // Build parameter list
        for (Integer id : ids) {
            idList.add(new Object[]{id});
        }
        // Batch delete
        int[] item = jdbcTemplate.batchUpdate(sql, idList);
        jdbcTemplate.update(sql_1);
        jdbcTemplate.update(sql_2);
        return item;
    }

    /**
     * select device
     * @return
     */
    public List<Device> selectAllDevice(int hospitalId){

        // Parameterized queries avoid SQL injection
        String sql = "SELECT * FROM device WHERE hospitalId = ?";
        List<Device> query = jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(Device.class), hospitalId);
        System.out.println(query);
        return query;
    }


    /**
     * fuzzy query
     * @param device
     * @return
     */
    public List<Device> selectByItem(Device device) {
        System.out.println("test:" + device);
        // Build the basic SQL and parameter list
        StringBuilder sql = new StringBuilder("SELECT * FROM device");

        //Dynamic table name stitching
        sql.append(" WHERE 1=1 ");
        List<Object> params = new ArrayList<>();

        //Dynamic concatenation of query conditions
        if (device.getHospitalId() > -1) {
            sql.append(" AND hospitalId = ?");
            params.add(device.getHospitalId());
        }
        if (device.getName() != null && device.getName() != "") {
            sql.append(" AND name LIKE ?");
            params.add("%" + device.getName() + "%");
        }
        if (device.getType() != null && device.getType() != "") {
            sql.append(" AND type LIKE ?");
            params.add("%" + device.getType() + "%");
        }

        System.out.println("sql: "+sql.toString());
        List<Device> query = jdbcTemplate.query(sql.toString(), params.toArray(), new BeanPropertyRowMapper<>(Device.class));
        System.out.println("query" + query);
        return query;

    }

    /**
     * Query data by name
     * @param name
     * @return
     */
    public Object getDeviceByName(String name){
        try {
            // 查询 device 表
            String sql = "select * from device where name=?";
            return jdbcTemplate.queryForObject(sql, new Object[]{name}, new BeanPropertyRowMapper<>(Device.class));
        } catch (Exception e) {
            e.printStackTrace();
        }
        // 如果所有查询都为空，返回 null
        return null;
    }


    /**
     * insert device
     * @param device
     */
    public Result insertDeviceInform(Device device) {

        //insert data
        SimpleJdbcInsert insert = new SimpleJdbcInsert(jdbcTemplate)
                .withTableName("device")
                .usingGeneratedKeyColumns("id");

        Map<String, Object> parameters = new HashMap<>();
        parameters.put("Id",device.getId());
        parameters.put("hospitalId",device.getHospitalId());
        parameters.put("name",device.getName());
        parameters.put("type",device.getType());
        parameters.put("freeTime", device.getFreeTime());


        Number number = insert.executeAndReturnKey(parameters);
        if(number.longValue() > 0){
            return Result.success(ResponseCode.SUCCESS);
        }else {
            return Result.error(ResponseCode.ERROR);
        }
    }

}
