package com.cardiff.client_project.mapper;

import com.cardiff.client_project.constant.Authority;
import com.cardiff.client_project.constant.ResponseCode;
import com.cardiff.client_project.pojo.dto.SelectDTO;
import com.cardiff.client_project.pojo.entity.Hospital;
import com.cardiff.client_project.pojo.vo.HospitalAdminVO;

import com.cardiff.client_project.pojo.vo.SelectVO;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.simple.SimpleJdbcInsert;
import org.springframework.stereotype.Repository;


import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Repository
public class HospitalAdminMapper {

    @Autowired
    JdbcTemplate jdbcTemplate;;


    /**
     * select admin
     * @return
     */
    public  List<HospitalAdminVO> selectAllAdmin() {

        // Parameterized queries avoid SQL injection
        String sql = "SELECT * FROM common_admin ORDER BY status DESC";
        List<HospitalAdminVO> query = jdbcTemplate.query(sql,new BeanPropertyRowMapper<>(HospitalAdminVO.class));
        return query;
    }


    /**
     * select hospital
     * @return
     */
    public List<Hospital> selectAllHospital(){

        // Parameterized queries avoid SQL injection
        String sql = "SELECT * FROM hospital ORDER BY status DESC";
        List<Hospital> query = jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(Hospital.class));
        System.out.println(query);
        return query;
    }


    /**
     * fuzzy query
     * @param selectDTO
     * @return
     */
    public List<SelectVO> selectByItem(SelectDTO selectDTO) {
        System.out.println("test:"+selectDTO);
        // Get query type
        String type = selectDTO.getType();
        // Build the basic SQL and parameter list
        StringBuilder sql = new StringBuilder("SELECT * FROM");

        if(type.contains("hospital")){
            sql.append(" hospital ");
        }

        //Dynamic table name stitching
        sql.append(" WHERE 1=1 ");
        List<Object> params = new ArrayList<>();

        //Dynamic concatenation of query conditions
        if (selectDTO.getName() != null && selectDTO.getName()!="") {
            sql.append(" AND name LIKE ?");
            params.add("%" + selectDTO.getName() + "%");
        }
        if (selectDTO.getPhone() != null && selectDTO.getPhone()!="") {
            sql.append(" AND phone LIKE ?");
            params.add("%" + selectDTO.getPhone() + "%");
        }
        if (selectDTO.getAddress() != null && selectDTO.getAddress()!="") {
            sql.append(" AND address LIKE ?");
            params.add("%" + selectDTO.getAddress() + "%");
        }
        if (Integer.valueOf(selectDTO.getStatus())!=null) {
            sql.append(" AND status = ?, ");
            params.add(selectDTO.getStatus());
        }
        sql.setLength(sql.length() - 2);

        System.out.println("sql: "+sql.toString());
        List<SelectVO> query = jdbcTemplate.query(sql.toString(), params.toArray(), new BeanPropertyRowMapper<>(SelectVO.class));
        System.out.println("quert"+query);
        return query;

    }

    /**
     * Query data by name
     * @param username
     * @return
     */
    public Object getInforByName(String username){

        try {
            // 1. 查询 hospital 表
            String sql = "select * from hospital where email=?";
            return jdbcTemplate.queryForObject(sql, new Object[]{username}, new BeanPropertyRowMapper<>(Hospital.class));
        } catch (Exception s) {

        }
        // 如果所有查询都为空，返回 null
        return null;
    }

    /**
     * Get role permissions based on id
     * @param roleId
     * @return
     */
    public String getTypeById(int roleId) {
        String sql="SELECT type from role where roleId=?;";
        String type= jdbcTemplate.queryForObject(sql, new Object[]{roleId}, String.class);
        return type;
    }

}
