package com.cardiff.client_project.mapper;

import com.cardiff.client_project.constant.ResponseCode;
import com.cardiff.client_project.pojo.entity.Hospital;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.simple.SimpleJdbcInsert;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Repository
public class HospitalMapper {

    @Autowired
    JdbcTemplate jdbcTemplate;

    /**
     * select hospital
     * @return
     */
    public List<Hospital> selectAllHospital(){
        // Parameterized queries avoid SQL injection
        String sql = "SELECT * FROM hospital";
        List<Hospital> query = jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(Hospital.class));
        System.out.println(query);
        return query;
    }


    /**
     * fuzzy query
     * @param hospital
     * @return
     */
    public List<Hospital> selectByItem(Hospital hospital) {
        System.out.println("test:" + hospital);
        // Build the basic SQL and parameter list
        StringBuilder sql = new StringBuilder("SELECT * FROM hospital");

        //Dynamic table name stitching
        sql.append(" WHERE 1=1 ");
        List<Object> params = new ArrayList<>();

        //Dynamic concatenation of query conditions
        if (hospital.getName() != null && hospital.getName() != "") {
            sql.append(" AND name LIKE ?");
            params.add("%" + hospital.getName() + "%");
        }
        if (hospital.getPhone() != null && hospital.getPhone() != "") {
            sql.append(" AND phone LIKE ?");
            params.add("%" + hospital.getPhone() + "%");
        }
        if (hospital.getAddress() != null && hospital.getAddress() != "") {
            sql.append(" AND address LIKE ?");
            params.add("%" + hospital.getAddress() + "%");
        }
        if (Integer.valueOf(hospital.getStatus()) != null) {
            sql.append(" AND status = ?, ");
            params.add(hospital.getStatus());
        }
        sql.setLength(sql.length() - 2);

        System.out.println("sql: " + sql.toString());
        List<Hospital> query = jdbcTemplate.query(sql.toString(), params.toArray(), new BeanPropertyRowMapper<>(Hospital.class));
        System.out.println("quert" + query);
        return query;


    }

    /**
     * Query data by name
     * @param name
     * @return
     */
    public Object getHospitalByName(String name){
        try {
            // 1. 查询 hospital 表
            String sql = "select * from hospital where name=?";
            return jdbcTemplate.queryForObject(sql, new Object[]{name}, new BeanPropertyRowMapper<>(Hospital.class));
        } catch (Exception e) {
            e.printStackTrace();
        }
        // 如果所有查询都为空，返回 null
        return null;
    }

    /**
     * Get role permissions based on id
     * @param roleId
     * @return
     */
    public String getTypeById(int roleId) {
        String sql="SELECT type from role where roleId=?;";
        String type= jdbcTemplate.queryForObject(sql, new Object[]{roleId}, String.class);
        return type;
    }


}