package com.cardiff.client_project.service.imp;

import com.cardiff.client_project.mapper.CommonAdminHospitalMapper;
import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.pojo.vo.NurseVO;
import com.cardiff.client_project.service.CommonAdminHospitalService;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class CommonAdminHospitalServiceImp implements CommonAdminHospitalService {

    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Autowired
    private CommonAdminHospitalMapper commonAdminHospitalMapper;

    @Override
    public List<HospitalDTO> getAllHospitals() {
        String sql = "SELECT * FROM hospital";
        return jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(HospitalDTO.class));
    }

    @Override
    public List<HospitalDTO> searchHospitals(String name, String location) {
        StringBuilder sql = new StringBuilder("SELECT * FROM hospital WHERE 1=1");
        if (name != null && !name.isEmpty()) {
            sql.append(" AND name LIKE ?");
        }
        if (location != null && !location.isEmpty()) {
            sql.append(" AND address LIKE ?");
        }
        return jdbcTemplate.query(sql.toString(), new BeanPropertyRowMapper<>(HospitalDTO.class),
                name != null ? "%" + name + "%" : null,
                location != null ? "%" + location + "%" : null);
    }

    @Override
    public void addHospital(HospitalDTO hospital) {
        if (hospital.getName() == null || hospital.getAddress() == null ||
                hospital.getPhone() == null || hospital.getTotalBeds() <= 0 ||
                hospital.getAvailableBeds() < 0) {
            throw new IllegalArgumentException("Invalid hospital data: Missing or incorrect fields.");
        }

        double occupancyRate = 1.0 - (double) hospital.getAvailableBeds() / hospital.getTotalBeds();

        String sql = "INSERT INTO hospital (name, address, phone, totalBeds, availableBeds, occupancyRate) VALUES (?, ?, ?, ?, ?, ?)";
        jdbcTemplate.update(sql, hospital.getName(), hospital.getAddress(), hospital.getPhone(),
                hospital.getTotalBeds(), hospital.getAvailableBeds(), occupancyRate);
    }

    @Override
    public Result add(Object entity) {
        return null;
    }

    @Override
    public void updateHospital(HospitalDTO hospital) {
        if (hospital.getId() <= 0 || hospital.getName() == null || hospital.getAddress() == null ||
                hospital.getPhone() == null || hospital.getTotalBeds() <= 0 || hospital.getAvailableBeds() < 0) {
            throw new IllegalArgumentException("Invalid hospital data: Missing or incorrect fields.");
        }

        String sql = "UPDATE hospital SET name = ?, address = ?, phone = ?, totalBeds = ?, availableBeds = ?, occupancyRate = ? WHERE id = ?";
        double occupancyRate = 1.0 - (double) hospital.getAvailableBeds() / hospital.getTotalBeds();

        int rowsUpdated = jdbcTemplate.update(sql, hospital.getName(), hospital.getAddress(), hospital.getPhone(),
                hospital.getTotalBeds(), hospital.getAvailableBeds(), occupancyRate, hospital.getId());

        if (rowsUpdated == 0) {
            throw new IllegalArgumentException("No hospital found with ID " + hospital.getId());
        }
    }

    @Override
    public void deleteHospital(int id) {
        String sql = "DELETE FROM hospital WHERE id = ?";
        jdbcTemplate.update(sql, id);
    }


    @Override
    public List<NurseVO> getAllNurses() {
        return commonAdminHospitalMapper.findAllNurses();
    }

    @Override
    public List<NurseVO> searchNurses(String name, Integer hospitalId) {
        return commonAdminHospitalMapper.searchNurses(name, hospitalId);
    }

}
