package com.cardiff.client_project.service.imp;

import com.cardiff.client_project.mapper.NursingHomeMapper;
import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.service.NursingHomeService;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.dao.DataAccessException;

import java.util.List;

@Service
public class NursingHomeServiceImp implements NursingHomeService {

    @Autowired
    private NursingHomeMapper nursingHomeMapper;

    @Override
    public Result<List<HospitalDTO>> getAvailableBeds() {
        try {
            List<HospitalDTO> hospitals = nursingHomeMapper.findAllNursingHomes();
            if (hospitals == null || hospitals.isEmpty()) {
                return Result.error("No hospitals available");
            }
            return Result.success(hospitals);
        } catch (DataAccessException e) {
            return Result.error("Database error: " + e.getMessage());
        } catch (Exception e) {
            return Result.error("Internal server error");
        }
    }

    @Override
    public Result<HospitalDTO> insertPatientInfo(HospitalDTO hospitalDTO) {
        try {
            if (!validateHospitalData(hospitalDTO)) {
                return Result.error("Invalid hospital data");
            }
            int result = nursingHomeMapper.insertHospital(hospitalDTO);
            if (result > 0) {
                return Result.success(hospitalDTO);
            }
            return Result.error("Failed to insert hospital");
        } catch (DataAccessException e) {
            return Result.error("Database error: " + e.getMessage());
        } catch (Exception e) {
            return Result.error("Internal server error");
        }
    }

    @Override
    public Result<String> updatePatient(HospitalDTO hospitalDTO) {
        try {
            if (!validateHospitalData(hospitalDTO)) {
                return Result.error("Invalid hospital data");
            }
            int result = nursingHomeMapper.updateHospital(hospitalDTO);
            return result > 0 ? 
                Result.success("Hospital updated successfully") :
                Result.error("Failed to update hospital");
        } catch (Exception e) {
            return Result.error("Error updating hospital: " + e.getMessage());
        }
    }

    @Override
    public Result<String> deletePatientById(List<Integer> ids) {
        try {
            int[] results = nursingHomeMapper.deleteHospitalByIds(ids);
            return results.length > 0 ? 
                Result.success("Hospital deleted successfully") :
                Result.error("No hospitals were deleted");
        } catch (Exception e) {
            return Result.error("Error deleting hospital: " + e.getMessage());
        }
    }

    @Override
    public Result<List<HospitalDTO>> getAllPatients() {
        return getAvailableBeds();
    }

    @Override
    public Result<String> updateBedCount(int hospitalId, int currentPatients) {
        try {
            if (currentPatients < 0) {
                return Result.error("Patient count cannot be negative");
            }
            int result = nursingHomeMapper.updateBedCount(hospitalId, currentPatients);
            return result > 0 ? 
                Result.success("Bed count updated successfully") :
                Result.error("Failed to update bed count");
        } catch (Exception e) {
            return Result.error("Error updating bed count: " + e.getMessage());
        }
    }

    private boolean validateHospitalData(HospitalDTO hospitalDTO) {
        if (hospitalDTO == null) return false;
        return hospitalDTO.getName() != null &&
               !hospitalDTO.getName().trim().isEmpty() &&
               hospitalDTO.getLocation() != null &&
               !hospitalDTO.getLocation().trim().isEmpty() &&
               hospitalDTO.getPhone() != null &&
               !hospitalDTO.getPhone().trim().isEmpty() &&
               hospitalDTO.getTotalBeds() > 0 &&
               hospitalDTO.getAvailableBeds() >= 0 &&
               hospitalDTO.getAvailableBeds() <= hospitalDTO.getTotalBeds();
    }
}